function [] = offsets(pCallbacks)
%OFFSETDETAILS Creates the offset details window
%   Detailed explanation goes here

global artoaGui artoaWorkspace;

%% Initialize required variables

windowTitle = [ 'ARTOA4 - Float ' num2str(artoaWorkspace.float.floatname) ' - Offsets' ];


availableCallbacks = { ...
    'CloseRequestFcn', ...
    'tableSoundsourceOffsetsSelect', ...
    'tableSoundsourceOffsetsEdit', ...
    'buttonCalculateOffsets', ...
    'checkboxUseOffsets' ...
};

for i = 1:length(availableCallbacks) % check if a callback is undefined
    if ~isfield(pCallbacks, availableCallbacks{i})
        pCallbacks.(availableCallbacks{i}) = @(~, ~) false;
    end
end

%% Initialize offset details gui

artoaGui.figures.editOffsets = figure( ...
    'Name', windowTitle, ...
    'NumberTitle', 'off', ...
    'MenuBar','none', ...
    'Units', 'characters' ...
);

% adjust width
artoaGui.figures.editOffsets.Position(3) = 120;

artoaGui.editOffsets = struct();

set( ...
    artoaGui.figures.editOffsets, ...
    'CloseRequestFcn', ...
    @artoa.controller.edit.offsets.close ...
);

%% Setup position variables
left = 0.03;
fullwidth = 1 - (2 * left);

%% Initialize offset table

artoaGui.editOffsets.tableSoundsourceOffsets = uitable( ...
    artoaGui.figures.editOffsets, ...
    'Units', 'normalized', ...
    'Position', [left, 0.45, fullwidth, 0.5], ...
    'ColumnEditable', true, ...
    'CellSelectionCallback', pCallbacks.tableSoundsourceOffsetsSelect, ...
    'CellEditCallback', pCallbacks.tableSoundsourceOffsetsEdit ...
);

%% Optimum offsets frame
artoaGui.editOffsets.frameOptimumOffsets = uipanel( ...
    'Title', 'Offset controls', ...
    'Units', 'normalized', ...
    'BackgroundColor', 'white', ...
    'Position', [left .05 fullwidth/2 .35] ...
);

%% Setup calculate offsets button
artoaGui.editOffsets.buttonCalculateOffsets = uicontrol( ...
    'Parent', artoaGui.editOffsets.frameOptimumOffsets, ...
    'String', 'Calculate offsets', ...
    'Style', 'PushButton', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [.65 .1 .25 .2], ...
    'CallBack', pCallbacks.buttonCalculateOffsets ...
);

artoaGui.editOffsets.checkboxUseOffsets = uicontrol( ...
    'Parent', artoaGui.editOffsets.frameOptimumOffsets, ...
    'String', 'Use offsets', ...
    'Style', 'checkbox', ...
    'FontSize', 8, ...
    'Units', 'normalized', ...
    'Position', [left .75 fullwidth/2 .2], ...
    'CallBack', pCallbacks.checkboxUseOffsets ...
);


end

